import { useEffect, useState } from "react";
import { BrowserRouter as Router, Routes, Route, Navigate } from "react-router-dom";
import LoginPage from "./Pages/LoginPage";
import Navbar from "./components/Navbar/Navbar";
import CallsPage from "./Pages/Calls";
import CallPage from "./Pages/CallPage";
import { User } from "./types";

function App() {
  const [loading, setLoading] = useState(true);
  const [user, setUser] = useState<User>(null)
  const [showLoginPage, setShowLoginPage] = useState(true);

  useEffect(() => {
    try {
      let token = localStorage.getItem('token');
      let email = localStorage.getItem("email");
      let role = localStorage.getItem("role");

      if (!token || !email || !role) {
        setShowLoginPage(true); 
      } else {
        setUser({
          token, email, role
        })
        setShowLoginPage(false);
      }
      setLoading(false);
    } catch (err) {
      console.error('Error parsing user from localStorage:', err);
      setLoading(false);
    }
  }, []);


  if (loading) {
    return <div>Loading...</div>;
  }


  return (
    <Router>
      {showLoginPage ? (
        <LoginPage setShowLoginPage={setShowLoginPage} setUser={setUser} />
      ) : (
        <>
          <Routes>
            <Route path="/login" element={<LoginPage setShowLoginPage={setShowLoginPage} setUser={setUser} />} />

            <Route
              path="/calls"
              // element={user ? <AlertsPage user={user} /> : <Navigate to="/login" />}
              element={user 
                ? (
                  <div className="h-full flex-1 flex-col space-y-8 p-8 flex lg:mx-auto">
                    <Navbar user={user} />
                    <CallsPage />
                  </div>
                ) 
                : <Navigate to="/login" />}
            />
            <Route
              path="/call/:callId"
              // element={user ? <AlertsPage user={user} /> : <Navigate to="/login" />}
              element={user 
                ? (
                  <div className="h-full flex-1 flex-col space-y-8 p-8 flex lg:mx-auto">
                    <Navbar user={user} />
                    <CallPage />
                  </div>
                ) 
                : <Navigate to="/login" />}
            />

            {/* Fallback route */}
            <Route path="*" element={<Navigate to="/calls" />} />
          </Routes>
        </>
      )}
    </Router>
  );
}

export default App;