import { ColumnDef } from "@tanstack/react-table";
import { types } from "./data";

import { Call } from "./data";
import { DataTableRowActions } from "./data-table-row-actions";
import { Badge } from "@/components/ui/badge";
import { format } from 'date-fns';
import { toZonedTime } from 'date-fns-tz';


export const getCallColumns = (): ColumnDef<Call>[] => [
  {
    accessorKey: "id",
    header: "Call ID",
    cell: ({ row }) => {
      return <div className="">{row.getValue("id")}</div>;
    },
    size: 200,
  },
  {
    accessorKey: "customer_phone",
    header: "Customer Phone",
    cell: ({ row }) => {
      return <div className="">{row.getValue("customer_phone")}</div>;
    },
    size: 200,
  },
  {
    accessorKey: "call_type",
    header: "Call Type",
    cell: ({ row }) => {
      let type = row.getValue("call_type") as string;
      if (type === 'inboundPhoneCall') type = 'Inbound';
      else if (type === 'outboundPhoneCall') type = 'Outbound';
      else if (type === 'webCall') type = 'Web Call';

      return <div className="">{type}</div>;
    },
    size: 200,
  },
  {
    accessorKey: "call_received_at",
    header: "Call Received",
    cell: ({ row }) => {

      // const date = new Date(row.getValue("call_received_at") as string);
      // const formattedDate = format(date, 'MMM dd, yyyy h:mm a');

      const date = new Date(row.getValue("call_received_at") as string);

      // Convert UTC to your local time zone or keep it as UTC
      const utcDate = toZonedTime(date, 'UTC'); // Convert to UTC

      // Format the date
      const formattedDate = format(utcDate, 'MMM dd, yyyy h:mm a');

      return <div className="">{formattedDate}</div>;
      
    },
    size: 200,
  },
  {
    accessorKey: "call_duration",
    header: "Call Duration",
    cell: ({ row }) => {
      return <div className="">{row.getValue("call_duration")}</div>;
    },
    size: 200,
  },
  {
    accessorKey: "call_status",
    header: "Status",
    cell: ({ row }) => {
      let type = row.getValue("call_status") as string;
      const backgroundColorClass =
        // types.find((t) => t.value === type)?.color || "black";
        types.find((t) => type.startsWith(t.value))?.color || "black";

      type = type.replace(/_/g, " ").toUpperCase();
      return (
        <Badge
          className={`${backgroundColorClass} whitespace-nowrap text-[10px]`}
        >
          {type}
        </Badge>
      );
    },
    maxSize: 100,
  },
  {
    accessorKey: "call_end_reason",
    header: () => <div className="">Call End Reason</div>,
    cell: ({ row }) => {
      let reason = row.getValue("call_end_reason") as string || '-'
      reason = reason.split('-').join(' ');

      return <div className="capitalize">{reason}</div>;
    },
  },
   
  {
    id: "actions",
    accessorKey: "actions",
    header: "Action",
    cell: ({ row }) => (
      <DataTableRowActions
        row={row}
      />
    ),
    maxSize: 100,
  },
];
