import { Table } from "@tanstack/react-table"
import {
  ChevronLeft,
  ChevronRight,
  ChevronsLeft,
  ChevronsRight,
} from "lucide-react"

import { Button } from "@/components/ui/button"
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select"

interface DataTablePaginationProps<TData> {
  table: Table<TData>,
  itemsPerPage: number
  currentPage: number
  setCurrentPage: React.Dispatch<React.SetStateAction<number>> ,
  onPageChange: (direction: 'next' | 'prev', timestamp?: string) => void,
  calls: TData[]
}

export function DataTablePagination<TData>({
  table,
  itemsPerPage,
  currentPage,
  setCurrentPage,
  onPageChange,
  calls,
}: DataTablePaginationProps<TData>) {

  // const handleNextPage = () => {
  //   setCurrentPage(currentPage + 1)

  //   console.log("Fetch calls, next page")
  // }
  
  // const handlePreviousPage = () => {
  //   if (currentPage > 1) {
  //     setCurrentPage(currentPage - 1)
  //    console.log("Fetch calls, previous page")
  //   }
  // }

  const handleNextPage = () => {
    if (calls.length === 0) return;
    const lastCall = calls[calls.length - 1] as any;
    setCurrentPage(currentPage + 1);
    console.log("Last call", lastCall)
    onPageChange('next', lastCall.call_received_at);
  }
  
  const handlePreviousPage = () => {
    if (currentPage > 1 && calls.length > 0) {
      const firstCall = calls[0] as any;
      setCurrentPage(currentPage - 1);
      onPageChange('prev', firstCall.call_received_at);
    }
  }


  return (
    <div className="flex items-center justify-end px-2">
      <div className="flex items-center space-x-6 lg:space-x-8">
        <div className="flex items-center space-x-2">
          <p className="text-sm font-medium">Rows per page</p>
          <Select
            value={`${table.getState().pagination.pageSize}`}
            onValueChange={(value) => {
              table.setPageSize(Number(value))
              setCurrentPage(1)  // Reset to first page if items per page changes
            }}
          >
            <SelectTrigger className="h-8 w-[70px]">
              <SelectValue placeholder={table.getState().pagination.pageSize} />
            </SelectTrigger>
            <SelectContent side="top">
              {[25, 50, 75, 100].map((pageSize) => (
                <SelectItem key={pageSize} value={`${pageSize}`}>
                  {pageSize}
                </SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        {/* <div className="flex w-[100px] items-center justify-center text-sm font-medium">
          Page {table.getState().pagination.pageIndex + 1} of{" "}
          {table.getPageCount()}
        </div> */}
        <div className="flex items-center space-x-2">
          {/* <Button
            variant="outline"
            className="hidden h-8 w-8 p-0 lg:flex"
            onClick={() => setCurrentPage(1)}
            disabled={currentPage === 1}
          >
            <span className="sr-only">Go to first page</span>
            <ChevronsLeft />
          </Button> */}
          <Button
            variant="outline"
            className="h-8 w-8 p-0"
            onClick={handlePreviousPage}
            disabled={currentPage === 1}
          >
            <span className="sr-only">Go to previous page</span>
            <ChevronLeft />
          </Button>
          <Button
            variant="outline"
            className="h-8 w-8 p-0"
            onClick={handleNextPage}
            // disabled={currentPage === totalPages}
          >
            <span className="sr-only">Go to next page</span>
            <ChevronRight />
          </Button>
          {/* <Button
            variant="outline"
            className="hidden h-8 w-8 p-0 lg:flex"
            onClick={() => setCurrentPage(totalPages)}
            disabled={currentPage === totalPages}
          >
            <span className="sr-only">Go to last page</span>
            <ChevronsRight />
          </Button> */}
        </div>
      </div>
    </div>
  )
}
